@@ -128,7 +128,7 @@ void Scripting::runScript(const QString &path, const QString &name) {
     mScriptName = name;
 
 #if HAVE_QTWEBKITWIDGETS
-    QUrl fileName = QUrl::fromLocalFile(path + "index.html");
+    QUrl fileName = QUrl::fromLocalFile(path + QStringLiteral("index.html"));
     if(!mScriptingHtmlDialog) {
         mScriptingHtmlDialog = new ScriptingHtmlDialog(this);
         connect(mScriptingHtmlDialog, &QDialog::rejected, this, &Scripting::stopAllScripts);
@@ -209,7 +209,7 @@ void Scripting::loadContextMenu() {
             action->setToolTip(desktopFile.readComment());
             action->setIcon(QIcon(desktopFile.readIcon()));
             QString scriptPath = script;
-            scriptPath.truncate(scriptPath.lastIndexOf('/'));
+            scriptPath.truncate(scriptPath.lastIndexOf(QLatin1Char('/')));
             action->setProperty("scriptPath", QString(scriptPath + QLatin1Char('/')));
             connect(action, &QAction::triggered, this, &Scripting::runScriptSlot);
             mProcessList->addAction(action);
